@@ -1,31 +1,30 @@
-#[allow(unused_imports)]
-use tracing::{info, warn, debug, error, trace, instrument, span, Level};
 use error_chain::bail;
+#[allow(unused_imports)]
+use tracing::{debug, error, info, instrument, span, trace, warn, Level};
 
-use crate::redo::LogWritable;
 use crate::error::*;
 use crate::event::*;
+use crate::redo::LogWritable;
 use crate::transaction::*;
 
 use fxhash::FxHashSet;
-use std::sync::{Arc};
-use tokio::sync::RwLock;
+use multimap::MultiMap;
+use std::ops::*;
+use std::sync::Arc;
 use std::sync::RwLock as StdRwLock;
 use std::sync::RwLockWriteGuard as StdRwLockWriteGuard;
-use std::ops::*;
 use std::time::Duration;
-use multimap::MultiMap;
+use tokio::sync::RwLock;
 
-use crate::trust::*;
 use crate::meta::*;
 use crate::spec::*;
 use crate::time::*;
+use crate::trust::*;
 
 use super::*;
 
 #[derive(Debug)]
-pub(crate) struct ChainProtectedAsync
-{
+pub(crate) struct ChainProtectedAsync {
     pub(crate) chain: ChainOfTrust,
     pub(crate) default_format: MessageFormat,
     pub(crate) disable_new_roots: bool,
@@ -35,14 +34,16 @@ pub(crate) struct ChainProtectedAsync
     pub(crate) integrity: TrustMode,
 }
 
-impl ChainProtectedAsync
-{
-    pub(super) fn process(&mut self, mut sync: StdRwLockWriteGuard<ChainProtectedSync>, headers: Vec<EventHeader>, conversation: Option<&Arc<ConversationSession>>) -> Result<(), ChainCreationError>
-    {
+impl ChainProtectedAsync {
+    pub(super) fn process(
+        &mut self,
+        mut sync: StdRwLockWriteGuard<ChainProtectedSync>,
+        headers: Vec<EventHeader>,
+        conversation: Option<&Arc<ConversationSession>>,
+    ) -> Result<(), ChainCreationError> {
         let mut ret = ProcessError::default();
 
-        for header in headers.into_iter()
-        {
+        for header in headers.into_iter() {
             if let Result::Err(err) = sync.validate_event(&header, conversation) {
                 ret.validation_errors.push(err);
             }
@@ -64,9 +65,11 @@ impl ChainProtectedAsync
         Ok(ret.as_result()?)
     }
 
-    pub(crate) async fn feed_meta_data(&mut self, sync: &Arc<StdRwLock<ChainProtectedSync>>, meta: Metadata)
-        -> Result<(), CommitError>
-    {
+    pub(crate) async fn feed_meta_data(
+        &mut self,
+        sync: &Arc<StdRwLock<ChainProtectedSync>>,
+        meta: Metadata,
+    ) -> Result<(), CommitError> {
         let data = EventData {
             meta,
             data_bytes: None,
@@ -80,19 +83,27 @@ impl ChainProtectedAsync
         self.feed_async_internal(sync, &evts, None).await
     }
 
-    pub(super) async fn feed_async_internal(&mut self, sync: &Arc<StdRwLock<ChainProtectedSync>>, evts: &Vec<EventData>, conversation: Option<&Arc<ConversationSession>>)
-        -> Result<(), CommitError>
-    {
+    pub(super) async fn feed_async_internal(
+        &mut self,
+        sync: &Arc<StdRwLock<ChainProtectedSync>>,
+        evts: &Vec<EventData>,
+        conversation: Option<&Arc<ConversationSession>>,
+    ) -> Result<(), CommitError> {
         let mut errors = Vec::new();
         let mut validated_evts = Vec::new();
         {
             let mut sync = sync.write().unwrap();
-            for evt in evts.iter()
-            {
+            for evt in evts.iter() {
                 let header = evt.as_header()?;
 
                 #[cfg(feature = "enable_verbose")]
-                trace!("chain::evt[key={}]", header.meta.get_data_key().map_or_else(|| "none".to_string(), |h| h.to_string()));
+                trace!(
+                    "chain::evt[key={}]",
+                    header
+                        .meta
+                        .get_data_key()
+                        .map_or_else(|| "none".to_string(), |h| h.to_string())
+                );
 
                 match sync.validate_event(&header, conversation) {
                     Err(err) => {
@@ -120,7 +131,7 @@ impl ChainProtectedAsync
                 header.meta.strip_signatures();
                 header.meta.strip_public_keys();
             }
-            
+
             if header.is_empty() == false {
                 let _lookup = self.chain.redo.write(evt).await?;
                 self.chain.add_history(header);
@@ -132,20 +143,30 @@ impl ChainProtectedAsync
                 let err = errors.into_iter().next().unwrap();
                 bail!(CommitErrorKind::ValidationError(err.0));
             }
-            bail!(CommitErrorKind::ValidationError(ValidationErrorKind::Many(errors)));
+            bail!(CommitErrorKind::ValidationError(ValidationErrorKind::Many(
+                errors
+            )));
         }
 
         Ok(())
     }
 
-    pub fn range<'a, R>(&'a self, range: R) -> impl DoubleEndedIterator<Item = (&'a ChainTimestamp, &'a EventHeaderRaw)>
-    where R: RangeBounds<ChainTimestamp>
+    pub fn range<'a, R>(
+        &'a self,
+        range: R,
+    ) -> impl DoubleEndedIterator<Item = (&'a ChainTimestamp, &'a EventHeaderRaw)>
+    where
+        R: RangeBounds<ChainTimestamp>,
     {
         self.chain.timeline.history.range(range)
     }
 
-    pub fn range_keys<'a, R>(&'a self, range: R) -> impl DoubleEndedIterator<Item = ChainTimestamp> + 'a
-    where R: RangeBounds<ChainTimestamp>
+    pub fn range_keys<'a, R>(
+        &'a self,
+        range: R,
+    ) -> impl DoubleEndedIterator<Item = ChainTimestamp> + 'a
+    where
+        R: RangeBounds<ChainTimestamp>,
     {
         let mut ret = self.range(range).map(|e| e.0).collect::<Vec<_>>();
         ret.dedup();
@@ -153,14 +174,17 @@ impl ChainProtectedAsync
     }
 
     #[allow(dead_code)]
-    pub fn range_values<'a, R>(&'a self, range: R) -> impl DoubleEndedIterator<Item = &'a EventHeaderRaw>
-    where R: RangeBounds<ChainTimestamp>
+    pub fn range_values<'a, R>(
+        &'a self,
+        range: R,
+    ) -> impl DoubleEndedIterator<Item = &'a EventHeaderRaw>
+    where
+        R: RangeBounds<ChainTimestamp>,
     {
         self.range(range).map(|e| e.1)
     }
 
-    pub(crate) async fn notify(lock: Arc<RwLock<ChainProtectedAsync>>, evts: Vec<EventData>)
-    {
+    pub(crate) async fn notify(lock: Arc<RwLock<ChainProtectedAsync>>, evts: Vec<EventData>) {
         // Build a map of event parents that will be used in the BUS notifications
         let mut notify_map = MultiMap::new();
         for evt in evts {
@@ -171,18 +195,16 @@ impl ChainProtectedAsync
 
         let mut to_remove = MultiMap::new();
 
-        
-        if notify_map.is_empty() == false
-        {
+        if notify_map.is_empty() == false {
             {
                 // Push the events to all the listeners
-                let lock = lock.read().await;                
+                let lock = lock.read().await;
                 for (k, v) in notify_map {
                     if let Some(targets) = lock.listeners.get_vec(&k) {
                         for target in targets {
                             for evt in v.iter() {
                                 match target.sender.send(evt.clone()).await {
-                                    Ok(()) => { },
+                                    Ok(()) => {}
                                     Err(_) => {
                                         to_remove.insert(k.clone(), target.id);
                                         break;
@@ -203,13 +225,12 @@ impl ChainProtectedAsync
                         targets.retain(|a| to_remove.contains(&a.id) == false);
                     }
                 }
-            } 
+            }
         }
     }
 
-    pub fn set_integrity_mode(&mut self, mode: TrustMode)
-    {
+    pub fn set_integrity_mode(&mut self, mode: TrustMode) {
         debug!("switching to {}", mode);
         self.integrity = mode;
     }
-}
\ No newline at end of file
+}
