@@ -1,7 +1,6 @@
 #[derive(Debug, Clone, Default)]
-pub struct Throttle
-{
+pub struct Throttle {
     pub download_per_second: Option<u64>,
     pub upload_per_second: Option<u64>,
     pub read_only: bool,
-}
\ No newline at end of file
+}
