@@ -1,8 +1,8 @@
 #![cfg(test)]
-#[allow(unused_imports)]
-use tracing::{info, warn, debug, error, trace, instrument, span, Level};
-#[cfg(feature="enable_dns")]
+#[cfg(feature = "enable_dns")]
 use std::{net::IpAddr, str::FromStr};
+#[allow(unused_imports)]
+use tracing::{debug, error, info, instrument, span, trace, warn, Level};
 
 use super::*;
 
@@ -22,9 +22,12 @@ pub(crate) fn mock_test_config() -> ConfAte {
 
 pub(crate) fn mock_test_mesh(port: u16) -> ConfMesh {
     let mut roots = Vec::new();
-    #[cfg(feature="enable_dns")]
-    roots.push(MeshAddress::new(IpAddr::from_str("127.0.0.1").unwrap(), port));
-    #[cfg(not(feature="enable_dns"))]
+    #[cfg(feature = "enable_dns")]
+    roots.push(MeshAddress::new(
+        IpAddr::from_str("127.0.0.1").unwrap(),
+        port,
+    ));
+    #[cfg(not(feature = "enable_dns"))]
     roots.push(MeshAddress::new("localhost", port));
 
     let ret = ConfMesh::new("localhost", roots.iter());
@@ -36,5 +39,8 @@ fn test_config_mocking() {
     crate::utils::bootstrap_test_env();
 
     let cfg = mock_test_mesh(4001);
-    assert_eq!(cfg.roots.iter().next().unwrap().host.to_string(), "127.0.0.1");
-}
\ No newline at end of file
+    assert_eq!(
+        cfg.roots.iter().next().unwrap().host.to_string(),
+        "127.0.0.1"
+    );
+}
