@@ -1,14 +1,14 @@
-#[allow(unused_imports)]
-use tracing::{info, warn, debug, error, trace, instrument, span, Level};
-use serde::{Serialize, Deserialize};
-use std::{io::ErrorKind};
-use std::result::Result;
-use pqcrypto_falcon_wasi::falcon512;
-use pqcrypto_falcon_wasi::falcon1024;
-use pqcrypto_traits_wasi::sign::{DetachedSignature, PublicKey as PQCryptoPublicKey};
-use pqcrypto_traits_wasi::sign::SecretKey as PQCryptoSecretKey;
-use crate::utils::vec_serialize;
 use crate::utils::vec_deserialize;
+use crate::utils::vec_serialize;
+use pqcrypto_falcon_wasi::falcon1024;
+use pqcrypto_falcon_wasi::falcon512;
+use pqcrypto_traits_wasi::sign::SecretKey as PQCryptoSecretKey;
+use pqcrypto_traits_wasi::sign::{DetachedSignature, PublicKey as PQCryptoPublicKey};
+use serde::{Deserialize, Serialize};
+use std::io::ErrorKind;
+use std::result::Result;
+#[allow(unused_imports)]
+use tracing::{debug, error, info, instrument, span, trace, warn, Level};
 
 use super::*;
 
@@ -35,22 +35,25 @@ pub enum PrivateSignKey {
     },
 }
 
-impl PrivateSignKey
-{
+impl PrivateSignKey {
     #[allow(dead_code)]
     pub fn generate(size: KeySize) -> PrivateSignKey {
         match size {
             KeySize::Bit128 | KeySize::Bit192 => {
                 let (pk, sk) = falcon512::keypair();
                 PrivateSignKey::Falcon512 {
-                    pk: PublicSignKey::Falcon512 { pk: Vec::from(pk.as_bytes()) },
+                    pk: PublicSignKey::Falcon512 {
+                        pk: Vec::from(pk.as_bytes()),
+                    },
                     sk: Vec::from(sk.as_bytes()),
                 }
-            },
+            }
             KeySize::Bit256 => {
                 let (pk, sk) = falcon1024::keypair();
                 PrivateSignKey::Falcon1024 {
-                    pk: PublicSignKey::Falcon1024 { pk: Vec::from(pk.as_bytes()) },
+                    pk: PublicSignKey::Falcon1024 {
+                        pk: Vec::from(pk.as_bytes()),
+                    },
                     sk: Vec::from(sk.as_bytes()),
                 }
             }
@@ -60,12 +63,8 @@ impl PrivateSignKey
     #[allow(dead_code)]
     pub fn as_public_key<'a>(&'a self) -> &'a PublicSignKey {
         match &self {
-            PrivateSignKey::Falcon512 { sk: _, pk } => {
-                pk
-            },
-            PrivateSignKey::Falcon1024 { sk: _, pk } => {
-                pk
-            },
+            PrivateSignKey::Falcon512 { sk: _, pk } => pk,
+            PrivateSignKey::Falcon1024 { sk: _, pk } => pk,
         }
     }
 
@@ -78,7 +77,7 @@ impl PrivateSignKey
     }
 
     #[allow(dead_code)]
-    pub fn pk<'a>(&'a self) -> &'a [u8] { 
+    pub fn pk<'a>(&'a self) -> &'a [u8] {
         match &self {
             PrivateSignKey::Falcon512 { pk, sk: _ } => pk.pk(),
             PrivateSignKey::Falcon1024 { pk, sk: _ } => pk.pk(),
@@ -86,7 +85,7 @@ impl PrivateSignKey
     }
 
     #[allow(dead_code)]
-    pub fn sk<'a>(&'a self) -> &'a [u8] { 
+    pub fn sk<'a>(&'a self) -> &'a [u8] {
         match &self {
             PrivateSignKey::Falcon512 { pk: _, sk } => &sk[..],
             PrivateSignKey::Falcon1024 { pk: _, sk } => &sk[..],
@@ -99,21 +98,31 @@ impl PrivateSignKey
             PrivateSignKey::Falcon512 { pk: _, sk } => {
                 let sk = match falcon512::SecretKey::from_bytes(&sk[..]) {
                     Ok(sk) => sk,
-                    Err(err) => { return Result::Err(std::io::Error::new(ErrorKind::Other, format!("Failed to decode the secret key ({}).", err))); },
+                    Err(err) => {
+                        return Result::Err(std::io::Error::new(
+                            ErrorKind::Other,
+                            format!("Failed to decode the secret key ({}).", err),
+                        ));
+                    }
                 };
                 let sig = falcon512::detached_sign(data, &sk);
                 Vec::from(sig.as_bytes())
-            },
+            }
             PrivateSignKey::Falcon1024 { pk: _, sk } => {
                 let sk = match falcon1024::SecretKey::from_bytes(&sk[..]) {
                     Ok(sk) => sk,
-                    Err(err) => { return Result::Err(std::io::Error::new(ErrorKind::Other, format!("Failed to decode the secret key ({}).", err))); },
+                    Err(err) => {
+                        return Result::Err(std::io::Error::new(
+                            ErrorKind::Other,
+                            format!("Failed to decode the secret key ({}).", err),
+                        ));
+                    }
                 };
                 let sig = falcon1024::detached_sign(data, &sk);
                 Vec::from(sig.as_bytes())
-            },
+            }
         };
-        
+
         Ok(ret)
     }
 
@@ -125,13 +134,15 @@ impl PrivateSignKey
     }
 }
 
-impl std::fmt::Display
-for PrivateSignKey
-{
+impl std::fmt::Display for PrivateSignKey {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         match self {
-            PrivateSignKey::Falcon512 { pk: _, sk: _ } => write!(f, "falcon512:pk:{}+sk", self.hash()),
-            PrivateSignKey::Falcon1024 { pk: _, sk: _ } => write!(f, "falcon1024:pk:{}+sk", self.hash()),
+            PrivateSignKey::Falcon512 { pk: _, sk: _ } => {
+                write!(f, "falcon512:pk:{}+sk", self.hash())
+            }
+            PrivateSignKey::Falcon1024 { pk: _, sk: _ } => {
+                write!(f, "falcon1024:pk:{}+sk", self.hash())
+            }
         }
     }
 }
@@ -152,13 +163,12 @@ pub enum PublicSignKey {
     Falcon1024 {
         #[serde(serialize_with = "vec_serialize", deserialize_with = "vec_deserialize")]
         pk: Vec<u8>,
-    }
+    },
 }
 
-impl PublicSignKey
-{
+impl PublicSignKey {
     #[allow(dead_code)]
-    pub fn pk<'a>(&'a self) -> &'a [u8] { 
+    pub fn pk<'a>(&'a self) -> &'a [u8] {
         match &self {
             PublicSignKey::Falcon512 { pk } => &pk[..],
             PublicSignKey::Falcon1024 { pk } => &pk[..],
@@ -172,7 +182,7 @@ impl PublicSignKey
             PublicSignKey::Falcon1024 { pk } => AteHash::from_bytes(&pk[..]),
         }
     }
-    
+
     #[allow(dead_code)]
     pub fn verify(&self, data: &[u8], sig: &[u8]) -> Result<bool, pqcrypto_traits_wasi::Error> {
         let ret = match &self {
@@ -180,25 +190,23 @@ impl PublicSignKey
                 let pk = falcon512::PublicKey::from_bytes(&pk[..])?;
                 let sig = falcon512::DetachedSignature::from_bytes(sig)?;
                 falcon512::verify_detached_signature(&sig, data, &pk).is_ok()
-            },
+            }
             PublicSignKey::Falcon1024 { pk } => {
                 let pk = falcon1024::PublicKey::from_bytes(&pk[..])?;
                 let sig = falcon1024::DetachedSignature::from_bytes(sig)?;
                 falcon1024::verify_detached_signature(&sig, data, &pk).is_ok()
             }
         };
-        
+
         Ok(ret)
     }
 }
 
-impl std::fmt::Display
-for PublicSignKey
-{
+impl std::fmt::Display for PublicSignKey {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         match self {
             PublicSignKey::Falcon512 { pk: _ } => write!(f, "falcon512:pk:{}", self.hash()),
             PublicSignKey::Falcon1024 { pk: _ } => write!(f, "falcon1024:pk:{}", self.hash()),
         }
     }
-}
\ No newline at end of file
+}
