@@ -1,32 +1,34 @@
 #[allow(unused_imports)]
-use tracing::{info, warn, debug, error, trace, instrument, span, Level};
+use tracing::{debug, error, info, instrument, span, trace, warn, Level};
 
 use super::*;
 
 #[derive(Debug, Default)]
-pub struct ProcessError
-{
+pub struct ProcessError {
     pub sink_errors: Vec<SinkError>,
     pub validation_errors: Vec<ValidationError>,
 }
 
 impl ProcessError {
     pub fn has_errors(&self) -> bool {
-        if self.sink_errors.is_empty() == false { return true; }
-        if self.validation_errors.is_empty() == false { return true; }
+        if self.sink_errors.is_empty() == false {
+            return true;
+        }
+        if self.validation_errors.is_empty() == false {
+            return true;
+        }
         false
     }
 
     pub fn as_result(self) -> Result<(), ProcessError> {
         match self.has_errors() {
             true => Err(self),
-            false => Ok(())
+            false => Ok(()),
         }
     }
 }
 
-impl std::fmt::Display
-for ProcessError {
+impl std::fmt::Display for ProcessError {
     fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
         let mut err = "Processing error - ".to_string();
         for sink in self.sink_errors.iter() {
@@ -39,7 +41,4 @@ for ProcessError {
     }
 }
 
-impl std::error::Error
-for ProcessError
-{
-}
\ No newline at end of file
+impl std::error::Error for ProcessError {}
