@@ -1,49 +1,44 @@
+use crate::engine::timeout;
 use async_trait::async_trait;
-use tracing::{info, warn, debug, error, trace, instrument, span, Level};
-use tracing_futures::{Instrument, WithSubscriber};
 use error_chain::bail;
-use std::sync::Mutex as StdMutex;
-use std::net::SocketAddr;
-use std::{sync::Arc, sync::Weak};
-use tokio::sync::mpsc;
-use tokio::sync::RwLock;
 use fxhash::FxHashMap;
-use std::sync::RwLock as StdRwLock;
+use std::net::SocketAddr;
 use std::ops::Rem;
+use std::sync::Mutex as StdMutex;
+use std::sync::RwLock as StdRwLock;
 use std::time::Duration;
 use std::time::Instant;
-use tokio::sync::broadcast;
-use crate::engine::timeout;
+use std::{sync::Arc, sync::Weak};
 use tokio::select;
+use tokio::sync::broadcast;
+use tokio::sync::mpsc;
+use tokio::sync::RwLock;
+use tracing::{debug, error, info, instrument, span, trace, warn, Level};
+use tracing_futures::{Instrument, WithSubscriber};
 
-use super::recoverable_session_pipe::*;
-use super::lock_request::*;
 use super::core::*;
-use crate::{anti_replay::AntiReplayPlugin, comms::*};
-use crate::trust::*;
-use crate::chain::*;
-use crate::error::*;
-use crate::conf::*;
-use crate::transaction::*;
+use super::lock_request::*;
 use super::msg::*;
-use crate::pipe::*;
-use crate::header::*;
-use crate::spec::*;
-use crate::loader::*;
+use super::recoverable_session_pipe::*;
+use crate::chain::*;
+use crate::conf::MeshConnectAddr;
+use crate::conf::*;
 use crate::crypto::*;
-use crate::meta::*;
-use crate::session::*;
-use crate::time::*;
 use crate::engine::*;
+use crate::error::*;
+use crate::header::*;
+use crate::loader::*;
 use crate::mesh::NodeId;
+use crate::meta::*;
+use crate::pipe::*;
+use crate::session::*;
+use crate::spec::*;
+use crate::time::*;
+use crate::transaction::*;
+use crate::trust::*;
+use crate::{anti_replay::AntiReplayPlugin, comms::*};
 
-#[cfg(feature="enable_dns")]
-type MeshConnectAddr = SocketAddr;
-#[cfg(not(feature="enable_dns"))]
-type MeshConnectAddr = crate::conf::MeshAddress;
-
-pub struct MeshSession
-{
+pub struct MeshSession {
     pub(super) addr: MeshAddress,
     pub(super) key: ChainKey,
     pub(super) sync_tolerance: Duration,
@@ -55,10 +50,8 @@ pub struct MeshSession
     pub(crate) status_tx: mpsc::Sender<ConnectionStatusChange>,
 }
 
-impl MeshSession
-{
-    pub(super) async fn connect
-    (
+impl MeshSession {
+    pub(super) async fn connect(
         builder: ChainBuilder,
         cfg_mesh: &ConfMesh,
         chain_key: &ChainKey,
@@ -66,10 +59,8 @@ impl MeshSession
         node_id: NodeId,
         hello_path: String,
         loader_local: impl Loader + 'static,
-        loader_remote: impl Loader + 'static
-    )
-    -> Result<Arc<Chain>, ChainCreationError>
-    {
+        loader_remote: impl Loader + 'static,
+    ) -> Result<Arc<Chain>, ChainCreationError> {
         debug!("new: chain_key={}", chain_key.to_string());
 
         #[cfg(feature = "enable_super_verbose")]
@@ -84,7 +75,7 @@ impl MeshSession
         // speed up the synchronization by skipping already loaded items
         let mut chain = {
             let chain_key = chain_key.clone();
-            
+
             // Generate a better key name
             let mut key_name = chain_key.name.clone();
             if key_name.starts_with("/") {
@@ -101,8 +92,9 @@ impl MeshSession
                 Some(Box::new(loader_local)),
                 true,
                 TrustMode::Centralized(CentralizedRole::Client),
-                TrustMode::Distributed
-            ).await?;
+                TrustMode::Distributed,
+            )
+            .await?;
             chain.remote_addr = Some(addr.clone());
             chain
         };
@@ -130,22 +122,22 @@ impl MeshSession
             metrics: Arc::clone(&chain.metrics),
             throttle: Arc::clone(&chain.throttle),
         };
-        
+
         // Add the pipe to the chain and cement it
         chain.proxy(Box::new(session));
         let chain = Arc::new(chain);
 
         // Set a reference to the chain and trigger it to connect!
         chain_store.lock().unwrap().replace(Arc::downgrade(&chain));
-        let on_disconnect = chain.pipe.connect(chain.exit.clone())
-            .await?;
+        let on_disconnect = chain.pipe.connect(chain.exit.clone()).await?;
 
         // Launch an automatic reconnect thread
         if temporal == false {
             trace!("launching auto-reconnect thread {}", chain_key.to_string());
-            TaskEngine::spawn(
-                RecoverableSessionPipe::auto_reconnect(Arc::downgrade(&chain), on_disconnect)
-            );
+            TaskEngine::spawn(RecoverableSessionPipe::auto_reconnect(
+                Arc::downgrade(&chain),
+                on_disconnect,
+            ));
         }
 
         // Ok we are good!
@@ -153,8 +145,12 @@ impl MeshSession
         Ok(chain)
     }
 
-    pub(super) async fn inbox_human_message(self: &Arc<MeshSession>, message: String, loader: &mut Option<Box<dyn Loader>>) -> Result<(), CommsError> {
-        trace!("human-message len={}",message.len());
+    pub(super) async fn inbox_human_message(
+        self: &Arc<MeshSession>,
+        message: String,
+        loader: &mut Option<Box<dyn Loader>>,
+    ) -> Result<(), CommsError> {
+        trace!("human-message len={}", message.len());
 
         if let Some(loader) = loader.as_mut() {
             loader.human_message(message);
@@ -163,52 +159,59 @@ impl MeshSession
         Ok(())
     }
 
-    pub(super) async fn inbox_events(self: &Arc<MeshSession>, evts: Vec<MessageEvent>, loader: &mut Option<Box<dyn Loader>>) -> Result<(), CommsError> {
+    pub(super) async fn inbox_events(
+        self: &Arc<MeshSession>,
+        evts: Vec<MessageEvent>,
+        loader: &mut Option<Box<dyn Loader>>,
+    ) -> Result<(), CommsError> {
         trace!("events cnt={}", evts.len());
 
         match self.chain.upgrade() {
-            Some(chain) =>
-            {
+            Some(chain) => {
                 // Convert the events but we do this differently depending on on if we are
                 // in a loading phase or a running phase
                 let feed_me = MessageEvent::convert_from(evts.into_iter());
                 let feed_me = match loader.as_mut() {
-                    Some(l) =>
-                    {
+                    Some(l) => {
                         // Feeding the events into the loader lets proactive feedback to be given back to
                         // the user such as progress bars
                         l.feed_events(&feed_me);
 
                         // When we are running then we proactively remove any duplicates to reduce noise
                         // or the likelihood of errors
-                        feed_me.into_iter()
-                            .filter(|e| {
-                                l.relevance_check(e) == false
-                            })
+                        feed_me
+                            .into_iter()
+                            .filter(|e| l.relevance_check(e) == false)
                             .collect::<Vec<_>>()
-                    },
-                    None => feed_me
+                    }
+                    None => feed_me,
                 };
-            
+
                 // We only feed the transactions into the local chain otherwise this will
                 // reflect events back into the chain-of-trust running on the server
-                chain.pipe.feed(ChainWork {
-                    trans: Transaction {
-                        scope: TransactionScope::Local,
-                        transmit: false,
-                        events: feed_me,
-                        timeout: Duration::from_secs(30),
-                        conversation: Some(Arc::clone(&self.inbound_conversation)),
-                    }
-                }).await?;
-            },
-            None => { }
+                chain
+                    .pipe
+                    .feed(ChainWork {
+                        trans: Transaction {
+                            scope: TransactionScope::Local,
+                            transmit: false,
+                            events: feed_me,
+                            timeout: Duration::from_secs(30),
+                            conversation: Some(Arc::clone(&self.inbound_conversation)),
+                        },
+                    })
+                    .await?;
+            }
+            None => {}
         };
 
         Ok(())
     }
 
-    pub(super) async fn inbox_confirmed(self: &Arc<MeshSession>, id: u64) -> Result<(), CommsError> {
+    pub(super) async fn inbox_confirmed(
+        self: &Arc<MeshSession>,
+        id: u64,
+    ) -> Result<(), CommsError> {
         trace!("commit_confirmed id={}", id);
 
         let r = {
@@ -223,21 +226,35 @@ impl MeshSession
         Ok(())
     }
 
-    pub(super) async fn inbox_commit_error(self: &Arc<MeshSession>, id: u64, err: String) -> Result<(), CommsError> {
+    pub(super) async fn inbox_commit_error(
+        self: &Arc<MeshSession>,
+        id: u64,
+        err: String,
+    ) -> Result<(), CommsError> {
         trace!("commit_error id={}, err={}", id, err);
 
-        let r= {
+        let r = {
             let mut lock = self.commit.lock().unwrap();
             lock.remove(&id)
         };
         if let Some(result) = r {
-            result.send(Err(CommitErrorKind::RootError(err).into())).await?;
+            result
+                .send(Err(CommitErrorKind::RootError(err).into()))
+                .await?;
         }
         Ok(())
     }
 
-    pub(super) fn inbox_lock_result(self: &Arc<MeshSession>, key: PrimaryKey, is_locked: bool) -> Result<(), CommsError> {
-        trace!("lock_result key={} is_locked={}", key.to_string(), is_locked);
+    pub(super) fn inbox_lock_result(
+        self: &Arc<MeshSession>,
+        key: PrimaryKey,
+        is_locked: bool,
+    ) -> Result<(), CommsError> {
+        trace!(
+            "lock_result key={} is_locked={}",
+            key.to_string(),
+            is_locked
+        );
 
         let mut remove = false;
         let mut guard = self.lock_requests.lock().unwrap();
@@ -246,16 +263,19 @@ impl MeshSession
                 remove = true;
             }
         }
-        if remove == true { guard.remove(&key); }
+        if remove == true {
+            guard.remove(&key);
+        }
         Ok(())
     }
 
-    pub(super) async fn record_delayed_upload(chain: &Arc<Chain>, pivot: ChainTimestamp) -> Result<(), CommsError>
-    {
+    pub(super) async fn record_delayed_upload(
+        chain: &Arc<Chain>,
+        pivot: ChainTimestamp,
+    ) -> Result<(), CommsError> {
         let mut guard = chain.inside_async.write().await;
         let from = guard.range_keys(pivot..).next();
-        if let Some(from) = from
-        {
+        if let Some(from) = from {
             if let Some(a) = guard.chain.timeline.pointers.get_delayed_upload(from) {
                 trace!("delayed_upload exists: {}..{}", a.from, a.to);
                 return Ok(());
@@ -264,13 +284,18 @@ impl MeshSession
             let to = guard.range_keys(from..).next_back();
             if let Some(to) = to {
                 trace!("delayed_upload new: {}..{}", from, to);
-                guard.feed_meta_data(&chain.inside_sync, Metadata {
-                    core: vec![CoreMetadata::DelayedUpload(MetaDelayedUpload {
-                        complete: false,
-                        from: from.clone(),
-                        to: to.clone()
-                    })]
-                }).await?;
+                guard
+                    .feed_meta_data(
+                        &chain.inside_sync,
+                        Metadata {
+                            core: vec![CoreMetadata::DelayedUpload(MetaDelayedUpload {
+                                complete: false,
+                                from: from.clone(),
+                                to: to.clone(),
+                            })],
+                        },
+                    )
+                    .await?;
             } else {
                 trace!("delayed_upload: {}..error", from);
             }
@@ -281,17 +306,25 @@ impl MeshSession
         Ok(())
     }
 
-    pub(super) async fn complete_delayed_upload(chain: &Arc<Chain>, from: ChainTimestamp, to: ChainTimestamp) -> Result<(), CommsError>
-    {
+    pub(super) async fn complete_delayed_upload(
+        chain: &Arc<Chain>,
+        from: ChainTimestamp,
+        to: ChainTimestamp,
+    ) -> Result<(), CommsError> {
         trace!("delayed_upload complete: {}..{}", from, to);
         let mut guard = chain.inside_async.write().await;
-        let _ = guard.feed_meta_data(&chain.inside_sync, Metadata {
-            core: vec![CoreMetadata::DelayedUpload(MetaDelayedUpload {
-                complete: true,
-                from,
-                to
-            })]
-        }).await?;
+        let _ = guard
+            .feed_meta_data(
+                &chain.inside_sync,
+                Metadata {
+                    core: vec![CoreMetadata::DelayedUpload(MetaDelayedUpload {
+                        complete: true,
+                        from,
+                        to,
+                    })],
+                },
+            )
+            .await?;
         Ok(())
     }
 
@@ -302,14 +335,12 @@ impl MeshSession
         to: Option<ChainTimestamp>,
         loader: &mut Option<Box<dyn Loader>>,
         root_keys: Vec<PublicSignKey>,
-        integrity: TrustMode
-    ) -> Result<(), CommsError>
-    {
+        integrity: TrustMode,
+    ) -> Result<(), CommsError> {
         // Declare variables
         let size = size;
 
-        if let Some(chain) = self.chain.upgrade()
-        {
+        if let Some(chain) = self.chain.upgrade() {
             #[cfg(feature = "enable_verbose")]
             trace!("start_of_history: chain_key={}", chain.key());
 
@@ -328,8 +359,7 @@ impl MeshSession
                 let next = {
                     let multi = chain.multi().await;
                     let guard = multi.inside_async.read().await;
-                    let mut iter = guard
-                        .range_keys(to..);
+                    let mut iter = guard.range_keys(to..);
                     iter.next();
                     iter.next()
                 };
@@ -338,7 +368,7 @@ impl MeshSession
                 }
             }
         }
-        
+
         // Tell the loader that we will be starting the load process of the history
         if let Some(loader) = loader {
             loader.start_of_history(size).await;
@@ -347,7 +377,11 @@ impl MeshSession
         Ok(())
     }
 
-    pub(super) async fn inbox_end_of_history(self: &Arc<MeshSession>, _pck: PacketWithContext<Message, ()>, loader: &mut Option<Box<dyn Loader>>) -> Result<(), CommsError> {
+    pub(super) async fn inbox_end_of_history(
+        self: &Arc<MeshSession>,
+        _pck: PacketWithContext<Message, ()>,
+        loader: &mut Option<Box<dyn Loader>>,
+    ) -> Result<(), CommsError> {
         trace!("end_of_history");
 
         // The end of the history means that the chain can now be actively used, its likely that
@@ -359,20 +393,34 @@ impl MeshSession
         Ok(())
     }
 
-    pub(super) async fn inbox_secure_with(self: &Arc<MeshSession>, session: crate::session::AteSessionUser) -> Result<(), CommsError> {
+    pub(super) async fn inbox_secure_with(
+        self: &Arc<MeshSession>,
+        session: crate::session::AteSessionUser,
+    ) -> Result<(), CommsError> {
         if let Some(chain) = self.chain.upgrade() {
             if let Some(root) = session.user.write_keys().next() {
-                trace!("received 'secure_with' secrets root_key={}", root.as_public_key().hash());
+                trace!(
+                    "received 'secure_with' secrets root_key={}",
+                    root.as_public_key().hash()
+                );
             } else {
                 trace!("received 'secure_with' secrets no_root");
             }
 
-            chain.inside_sync.write().unwrap().default_session.append(session.properties());
+            chain
+                .inside_sync
+                .write()
+                .unwrap()
+                .default_session
+                .append(session.properties());
         }
         Ok(())
     }
 
-    pub(super) async fn inbox_new_conversation(self: &Arc<MeshSession>, conversation_id: AteHash) -> Result<(), CommsError> {
+    pub(super) async fn inbox_new_conversation(
+        self: &Arc<MeshSession>,
+        conversation_id: AteHash,
+    ) -> Result<(), CommsError> {
         self.inbound_conversation.clear();
         self.outbound_conversation.clear();
         if let Some(mut a) = self.inbound_conversation.id.try_lock() {
@@ -394,97 +442,101 @@ impl MeshSession
         self: &Arc<MeshSession>,
         loader: &mut Option<Box<dyn Loader>>,
         pck: PacketWithContext<Message, ()>,
-    ) -> Result<(), CommsError>
-    {
+    ) -> Result<(), CommsError> {
         #[cfg(feature = "enable_super_verbose")]
         trace!("packet size={}", pck.data.bytes.len());
 
         match pck.packet.msg {
-            Message::StartOfHistory { size, from, to, root_keys, integrity }
-                => {
-                    Self::inbox_start_of_history(self, size, from, to, loader, root_keys, integrity)
-                        .instrument(span!(Level::DEBUG, "start-of-history"))
-                        .await?;
-                },
-            Message::HumanMessage { message }
-                => {
-                    Self::inbox_human_message(self, message, loader)
-                        .instrument(span!(Level::DEBUG, "human-message"))
-                        .await?;
-                },
-            Message::ReadOnly
-                => {
-                    error!("chain-of-trust is currently read-only - {}", self.key.to_string());
-                    self.cancel_commits(CommitErrorKind::ReadOnly).await;
-                    let _ = self.status_tx.send(ConnectionStatusChange::ReadOnly).await;
-                },
-            Message::Events { commit: _, evts }
-                => {
-                    let num_deletes = evts.iter().filter(|a| a.meta.get_tombstone().is_some()).count();
-                    let num_data = evts.iter().filter(|a| a.data.is_some()).count();
-                    Self::inbox_events(self, evts, loader)
-                        .instrument(span!(Level::DEBUG, "event", delete_cnt=num_deletes, data_cnt=num_data))
-                        .await?;
-                },
-            Message::Confirmed(id)
-                => {
-                    Self::inbox_confirmed(self, id)
-                        .instrument(span!(Level::DEBUG, "commit-confirmed"))
-                        .await?;
-                },
-            Message::CommitError { id, err }
-                => {
-                    Self::inbox_commit_error(self, id, err)
-                        .instrument(span!(Level::DEBUG, "commit-error"))
-                        .await?;
-                },
-            Message::LockResult { key, is_locked }
-                => {
-                    async move {
-                        Self::inbox_lock_result(self, key, is_locked)
+            Message::StartOfHistory {
+                size,
+                from,
+                to,
+                root_keys,
+                integrity,
+            } => {
+                Self::inbox_start_of_history(self, size, from, to, loader, root_keys, integrity)
+                    .instrument(span!(Level::DEBUG, "start-of-history"))
+                    .await?;
+            }
+            Message::HumanMessage { message } => {
+                Self::inbox_human_message(self, message, loader)
+                    .instrument(span!(Level::DEBUG, "human-message"))
+                    .await?;
+            }
+            Message::ReadOnly => {
+                error!(
+                    "chain-of-trust is currently read-only - {}",
+                    self.key.to_string()
+                );
+                self.cancel_commits(CommitErrorKind::ReadOnly).await;
+                let _ = self.status_tx.send(ConnectionStatusChange::ReadOnly).await;
+            }
+            Message::Events { commit: _, evts } => {
+                let num_deletes = evts
+                    .iter()
+                    .filter(|a| a.meta.get_tombstone().is_some())
+                    .count();
+                let num_data = evts.iter().filter(|a| a.data.is_some()).count();
+                Self::inbox_events(self, evts, loader)
+                    .instrument(span!(
+                        Level::DEBUG,
+                        "event",
+                        delete_cnt = num_deletes,
+                        data_cnt = num_data
+                    ))
+                    .await?;
+            }
+            Message::Confirmed(id) => {
+                Self::inbox_confirmed(self, id)
+                    .instrument(span!(Level::DEBUG, "commit-confirmed"))
+                    .await?;
+            }
+            Message::CommitError { id, err } => {
+                Self::inbox_commit_error(self, id, err)
+                    .instrument(span!(Level::DEBUG, "commit-error"))
+                    .await?;
+            }
+            Message::LockResult { key, is_locked } => {
+                async move { Self::inbox_lock_result(self, key, is_locked) }
+                    .instrument(span!(Level::DEBUG, "lock_result"))
+                    .await?;
+            }
+            Message::EndOfHistory => {
+                Self::inbox_end_of_history(self, pck, loader)
+                    .instrument(span!(Level::DEBUG, "end-of-history"))
+                    .await?;
+            }
+            Message::SecuredWith(session) => {
+                Self::inbox_secure_with(self, session)
+                    .instrument(span!(Level::DEBUG, "secured-with"))
+                    .await?;
+            }
+            Message::NewConversation { conversation_id } => {
+                Self::inbox_new_conversation(self, conversation_id)
+                    .instrument(span!(Level::DEBUG, "new-conversation"))
+                    .await?;
+            }
+            Message::FatalTerminate(fatal) => {
+                async move {
+                    if let Some(mut loader) = loader.take() {
+                        loader
+                            .failed(ChainCreationErrorKind::ServerRejected(fatal.clone()).into())
+                            .await;
                     }
-                        .instrument(span!(Level::DEBUG, "lock_result"))
-                        .await?;
-                },
-            Message::EndOfHistory
-                => {
-                    Self::inbox_end_of_history(self, pck, loader)
-                        .instrument(span!(Level::DEBUG, "end-of-history"))
-                        .await?;
-                },
-            Message::SecuredWith(session)
-                => {
-                    Self::inbox_secure_with(self, session)
-                        .instrument(span!(Level::DEBUG, "secured-with"))
-                        .await?;
-                },
-            Message::NewConversation { conversation_id }
-                => {
-                    Self::inbox_new_conversation(self, conversation_id)
-                        .instrument(span!(Level::DEBUG, "new-conversation"))
-                        .await?;
-                },
-            Message::FatalTerminate(fatal)
-                => {
-                    async move {
-                        if let Some(mut loader) = loader.take() {
-                            loader.failed(ChainCreationErrorKind::ServerRejected(fatal.clone()).into()).await;
-                        }
-                        warn!("mesh-session-err: {}", fatal);
-                    }
-                    .instrument(span!(Level::DEBUG, "fatal_terminate"))
-                    .await;
+                    warn!("mesh-session-err: {}", fatal);
+                }
+                .instrument(span!(Level::DEBUG, "fatal_terminate"))
+                .await;
 
-                    bail!(CommsErrorKind::Disconnected);
-                },
-            _ => { }
+                bail!(CommsErrorKind::Disconnected);
+            }
+            _ => {}
         };
 
         Ok(())
     }
 
-    pub(super) async fn cancel_commits(&self, reason: CommitErrorKind)
-    {
+    pub(super) async fn cancel_commits(&self, reason: CommitErrorKind) {
         let mut senders = Vec::new();
         {
             let mut guard = self.commit.lock().unwrap();
@@ -496,7 +548,7 @@ impl MeshSession
         for sender in senders.into_iter() {
             let reason = match &reason {
                 CommitErrorKind::ReadOnly => CommitErrorKind::ReadOnly,
-                _ => CommitErrorKind::Aborted
+                _ => CommitErrorKind::Aborted,
             };
             if let Err(err) = sender.send(Err(reason.into())).await {
                 warn!("mesh-session-cancel-err: {}", err.to_string());
@@ -504,16 +556,14 @@ impl MeshSession
         }
     }
 
-    pub(super) fn cancel_locks(&self)
-    {
+    pub(super) fn cancel_locks(&self) {
         let mut guard = self.lock_requests.lock().unwrap();
         for (_, sender) in guard.drain() {
             sender.cancel();
         }
     }
 
-    pub(super) fn cancel_sniffers(&self)
-    {
+    pub(super) fn cancel_sniffers(&self) {
         if let Some(guard) = self.chain.upgrade() {
             let mut lock = guard.inside_sync.write().unwrap();
             lock.sniffers.clear();
@@ -521,8 +571,7 @@ impl MeshSession
     }
 }
 
-pub(crate) struct MeshSessionProcessor
-{
+pub(crate) struct MeshSessionProcessor {
     pub(crate) addr: MeshAddress,
     pub(crate) node_id: NodeId,
     pub(crate) loader: Option<Box<dyn Loader>>,
@@ -531,11 +580,8 @@ pub(crate) struct MeshSessionProcessor
 }
 
 #[async_trait]
-impl InboxProcessor<Message, ()>
-for MeshSessionProcessor
-{
-    async fn process(&mut self, pck: PacketWithContext<Message, ()>) -> Result<(), CommsError>
-    {
+impl InboxProcessor<Message, ()> for MeshSessionProcessor {
+    async fn process(&mut self, pck: PacketWithContext<Message, ()>) -> Result<(), CommsError> {
         let session = match Weak::upgrade(&self.session) {
             Some(a) => a,
             None => {
@@ -544,32 +590,30 @@ for MeshSessionProcessor
             }
         };
 
-        MeshSession::inbox_packet(&session, &mut self.loader, pck)
-            .await?;
-        Ok(())        
+        MeshSession::inbox_packet(&session, &mut self.loader, pck).await?;
+        Ok(())
     }
 
-    async fn shutdown(&mut self, _sock_addr: MeshConnectAddr)
-    {
+    async fn shutdown(&mut self, _sock_addr: MeshConnectAddr) {
         info!("disconnected: {}:{}", self.addr.host, self.addr.port);
         if let Some(session) = self.session.upgrade() {
             session.cancel_commits(CommitErrorKind::Aborted).await;
             session.cancel_sniffers();
             session.cancel_locks();
         }
-        
+
         // We should only get here if the inbound connection is shutdown or fails
-        let _ = self.status_tx.send(ConnectionStatusChange::Disconnected).await;
+        let _ = self
+            .status_tx
+            .send(ConnectionStatusChange::Disconnected)
+            .await;
     }
 }
 
-impl Drop
-for MeshSession
-{
-    fn drop(&mut self)
-    {
+impl Drop for MeshSession {
+    fn drop(&mut self) {
         trace!("drop {}", self.key.to_string());
         self.cancel_locks();
         self.cancel_sniffers();
     }
-}
\ No newline at end of file
+}
