@@ -1,5 +1,5 @@
-use serde::{Serialize, Deserialize};
 use crate::signature::MetaSignWith;
+use serde::{Deserialize, Serialize};
 
 use crate::crypto::*;
 use crate::error::*;
@@ -10,8 +10,7 @@ use crate::time::*;
 use super::*;
 
 #[derive(Serialize, Deserialize, Debug, Clone)]
-pub enum CoreMetadata
-{
+pub enum CoreMetadata {
     None,
     Data(PrimaryKey),
     Tombstone(PrimaryKey),
@@ -37,9 +36,7 @@ impl Default for CoreMetadata {
     }
 }
 
-impl std::fmt::Display
-for CoreMetadata
-{
+impl std::fmt::Display for CoreMetadata {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         match self {
             CoreMetadata::None => write!(f, "none"),
@@ -48,9 +45,11 @@ for CoreMetadata
             CoreMetadata::Authorization(a) => write!(f, "auth({})", a),
             CoreMetadata::InitializationVector(a) => write!(f, "iv({})", a),
             CoreMetadata::PublicKey(a) => write!(f, "public_key({})", a.hash()),
-            CoreMetadata::EncryptedPrivateKey(a) => write!(f, "encrypt_private_key({})", a.as_public_key().hash()),
+            CoreMetadata::EncryptedPrivateKey(a) => {
+                write!(f, "encrypt_private_key({})", a.as_public_key().hash())
+            }
             CoreMetadata::Confidentiality(a) => write!(f, "confidentiality-{}", a),
-            CoreMetadata::Collection(a) => write!(f, "collection-{}", a ),
+            CoreMetadata::Collection(a) => write!(f, "collection-{}", a),
             CoreMetadata::Parent(a) => write!(f, "parent-{}", a),
             CoreMetadata::Timestamp(a) => write!(f, "timestamp-{}", a),
             CoreMetadata::Signature(a) => write!(f, "signature-{}", a),
@@ -64,14 +63,11 @@ for CoreMetadata
 }
 
 #[derive(Serialize, Deserialize, Debug, Default, Clone)]
-pub struct Metadata
-{
+pub struct Metadata {
     pub core: Vec<CoreMetadata>,
 }
 
-impl std::fmt::Display
-for Metadata
-{
+impl std::fmt::Display for Metadata {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         let mut first = true;
         write!(f, "meta[")?;
@@ -87,46 +83,41 @@ for Metadata
     }
 }
 
-impl Metadata
-{
-    pub fn get_authorization(&self) -> Option<&MetaAuthorization>
-    {
+impl Metadata {
+    pub fn get_authorization(&self) -> Option<&MetaAuthorization> {
         for core in &self.core {
             match core {
                 CoreMetadata::Authorization(a) => {
                     return Some(a);
-                },
+                }
                 _ => {}
             }
         }
-        
+
         None
     }
 
-    pub fn get_parent(&self) -> Option<&MetaParent>
-    {
+    pub fn get_parent(&self) -> Option<&MetaParent> {
         for core in &self.core {
             if let CoreMetadata::Parent(a) = core {
                 return Some(a);
             }
         }
-        
+
         None
     }
 
-    pub fn get_collections(&self) -> Vec<MetaCollection>
-    {
+    pub fn get_collections(&self) -> Vec<MetaCollection> {
         let mut ret = Vec::new();
         for core in &self.core {
             if let CoreMetadata::Collection(a) = core {
                 ret.push(a.clone());
             }
-        }        
+        }
         ret
     }
 
-    pub fn get_confidentiality(&self) -> Option<&MetaConfidentiality>
-    {
+    pub fn get_confidentiality(&self) -> Option<&MetaConfidentiality> {
         for core in &self.core {
             if let CoreMetadata::Confidentiality(a) = core {
                 return Some(a);
@@ -136,14 +127,16 @@ impl Metadata
     }
 
     pub fn generate_iv(&mut self) -> InitializationVector {
-        let mut core = self.core.clone()
+        let mut core = self
+            .core
+            .clone()
             .into_iter()
-            .filter(|m|  match m {
+            .filter(|m| match m {
                 CoreMetadata::InitializationVector(_) => false,
                 _ => true,
             })
             .collect::<Vec<_>>();
-        
+
         let iv = InitializationVector::generate();
         core.push(CoreMetadata::InitializationVector(iv.clone()));
         self.core = core;
@@ -154,22 +147,23 @@ impl Metadata
         for m in self.core.iter() {
             match m {
                 CoreMetadata::InitializationVector(iv) => return Result::Ok(iv),
-                _ => { }
+                _ => {}
             }
         }
         Result::Err(CryptoErrorKind::NoIvPresent.into())
     }
 
-    pub fn needs_signature(&self) -> bool
-    {
+    pub fn needs_signature(&self) -> bool {
         for core in &self.core {
             match core {
-                CoreMetadata::PublicKey(_) => {},
-                CoreMetadata::Signature(_) => {},
-                CoreMetadata::EncryptedPrivateKey(_) => {},
-                CoreMetadata::Confidentiality(_) => {},
-                CoreMetadata::DelayedUpload(_) => {},
-                _ => { return true; }
+                CoreMetadata::PublicKey(_) => {}
+                CoreMetadata::Signature(_) => {}
+                CoreMetadata::EncryptedPrivateKey(_) => {}
+                CoreMetadata::Confidentiality(_) => {}
+                CoreMetadata::DelayedUpload(_) => {}
+                _ => {
+                    return true;
+                }
             }
         }
 
@@ -177,30 +171,25 @@ impl Metadata
     }
 
     pub fn strip_signatures(&mut self) {
-        self.core.retain(|a| {
-            match a {
-                CoreMetadata::Signature(_) => false,
-                _ => true
-            }
+        self.core.retain(|a| match a {
+            CoreMetadata::Signature(_) => false,
+            _ => true,
         });
     }
 
     pub fn strip_public_keys(&mut self) {
-        self.core.retain(|a| {
-            match a {
-                CoreMetadata::PublicKey(_) => false,
-                _ => true
-            }
+        self.core.retain(|a| match a {
+            CoreMetadata::PublicKey(_) => false,
+            _ => true,
         });
     }
 
-    pub fn get_sign_with(&self) -> Option<&MetaSignWith>
-    {
+    pub fn get_sign_with(&self) -> Option<&MetaSignWith> {
         for core in &self.core {
             if let CoreMetadata::SignWith(a) = core {
                 return Some(a);
             }
-        }        
+        }
         None
     }
 
@@ -209,18 +198,16 @@ impl Metadata
             if let CoreMetadata::Timestamp(a) = core {
                 return Some(a);
             }
-        }        
+        }
         None
     }
 
     pub fn get_type_name(&self) -> Option<&MetaType> {
         self.core
             .iter()
-            .filter_map(|m| {
-                match m {
-                    CoreMetadata::Type(t) => Some(t),
-                    _ => None,
-                }
+            .filter_map(|m| match m {
+                CoreMetadata::Type(t) => Some(t),
+                _ => None,
             })
             .next()
     }
@@ -228,27 +215,24 @@ impl Metadata
     pub fn get_public_key(&self) -> Option<&PublicSignKey> {
         self.core
             .iter()
-            .filter_map(|m| {
-                match m {
-                    CoreMetadata::PublicKey(t) => Some(t),
-                    _ => None,
-                }
+            .filter_map(|m| match m {
+                CoreMetadata::PublicKey(t) => Some(t),
+                _ => None,
             })
             .next()
     }
 
     pub fn is_of_type<T: ?Sized>(&self) -> bool {
-        if let Some(m) = self.core
+        if let Some(m) = self
+            .core
             .iter()
-            .filter_map(|m| {
-                match m {
-                    CoreMetadata::Type(t) => Some(t),
-                    _ => None,
-                }
+            .filter_map(|m| match m {
+                CoreMetadata::Type(t) => Some(t),
+                _ => None,
             })
             .next()
         {
-            return m.type_name == std::any::type_name::<T>().to_string()
+            return m.type_name == std::any::type_name::<T>().to_string();
         }
 
         false
@@ -256,51 +240,43 @@ impl Metadata
 
     pub fn set_type_name<T: ?Sized>(&mut self) {
         let type_name = std::any::type_name::<T>().to_string();
-        
-        if self.core
+
+        if self
+            .core
             .iter_mut()
-            .filter_map(|m| {
-                match m {
-                    CoreMetadata::Type(t) => {
-                        t.type_name = type_name.clone();
-                        Some(t)
-                    },
-                    _ => None,
+            .filter_map(|m| match m {
+                CoreMetadata::Type(t) => {
+                    t.type_name = type_name.clone();
+                    Some(t)
                 }
+                _ => None,
             })
             .next()
             .is_none()
         {
-            self.core.push(CoreMetadata::Type(MetaType {
-                type_name,
-            }));
+            self.core.push(CoreMetadata::Type(MetaType { type_name }));
         }
     }
 
     pub fn is_reply_to_what(&self) -> Option<PrimaryKey> {
         self.core
             .iter()
-            .filter_map(|m| {
-                match m {
-                    CoreMetadata::Reply(a) => Some(a.clone()),
-                    _ => None,
-                }
+            .filter_map(|m| match m {
+                CoreMetadata::Reply(a) => Some(a.clone()),
+                _ => None,
             })
             .next()
     }
 
     pub fn get_delayed_upload(&self) -> Option<MetaDelayedUpload> {
-        self.core.iter().filter_map(
-            |m| {
-                match m
-                {
-                    CoreMetadata::DelayedUpload(k) => Some(k.clone()),
-                     _ => None
-                }
-            }
-        )
-        .next()
-    } 
+        self.core
+            .iter()
+            .filter_map(|m| match m {
+                CoreMetadata::DelayedUpload(k) => Some(k.clone()),
+                _ => None,
+            })
+            .next()
+    }
 
     pub fn include_in_history(&self) -> bool {
         if self.get_delayed_upload().is_some() {
@@ -312,4 +288,4 @@ impl Metadata
     pub fn is_empty(&self) -> bool {
         self.core.is_empty()
     }
-}
\ No newline at end of file
+}
