@@ -1,15 +1,12 @@
-use serde::{Serialize, Deserialize};
+use serde::{Deserialize, Serialize};
 
 #[derive(Serialize, Deserialize, Debug, Clone)]
-pub struct MetaType
-{
+pub struct MetaType {
     pub type_name: String,
 }
 
-impl std::fmt::Display
-for MetaType
-{
+impl std::fmt::Display for MetaType {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         write!(f, "{}", self.type_name)
     }
-}
\ No newline at end of file
+}
