@@ -1,27 +1,27 @@
 #[allow(unused_imports)]
-use tracing::{error, info, warn, debug};
+use tracing::{debug, error, info, warn};
 
 mod api;
 #[cfg(feature = "enable_local_fs")]
+mod appender;
+#[cfg(feature = "enable_local_fs")]
+mod archive;
+mod core;
+mod flags;
+mod flip;
+mod loader;
+#[cfg(feature = "enable_local_fs")]
 mod log_localfs;
 mod log_memdb;
 mod log_traits;
-mod flags;
-mod flip;
 mod magic;
-#[cfg(feature = "enable_local_fs")]
-mod appender;
-mod loader;
-#[cfg(feature = "enable_local_fs")]
-mod archive;
-mod core;
 mod test;
 
-pub use flags::OpenFlags;
-pub use loader::RedoLogLoader;
 pub use self::core::RedoLog;
 pub use api::LogWritable;
+pub use flags::OpenFlags;
+pub use loader::RedoLogLoader;
 
 pub(crate) use api::LogLookup;
 
-pub use log_traits::*;
\ No newline at end of file
+pub use log_traits::*;
