@@ -1,21 +1,20 @@
 #[allow(unused_imports)]
-use tracing::{error, info, debug};
+use tracing::{debug, error, info};
 
-use crate::error::*;
 use crate::conf::*;
+use crate::error::*;
 
-#[cfg(feature = "enable_ntp")]
-use std::{sync::Arc};
-use std::time::Duration;
-use std::time::SystemTime;
-use std::time::UNIX_EPOCH;
 #[cfg(feature = "enable_ntp")]
 use super::worker::NtpWorker;
 use super::ChainTimestamp;
+#[cfg(feature = "enable_ntp")]
+use std::sync::Arc;
+use std::time::Duration;
+use std::time::SystemTime;
+use std::time::UNIX_EPOCH;
 
 #[derive(Debug, Clone)]
-pub struct TimeKeeper
-{    
+pub struct TimeKeeper {
     pub tolerance: Duration,
     #[cfg(feature = "enable_ntp")]
     pub ntp_pool: String,
@@ -25,28 +24,23 @@ pub struct TimeKeeper
     pub(crate) ntp_worker: Option<Arc<NtpWorker>>,
 }
 
-impl TimeKeeper
-{
+impl TimeKeeper {
     #[allow(unused_variables)]
     #[allow(dead_code)]
-    pub async fn new(cfg: &ConfAte, tolerance_ms: u32) -> Result<TimeKeeper, TimeError>
-    {
+    pub async fn new(cfg: &ConfAte, tolerance_ms: u32) -> Result<TimeKeeper, TimeError> {
         let tolerance = Duration::from_millis(tolerance_ms as u64);
-        Ok(
-            TimeKeeper
-            {
-                tolerance: tolerance,
-                #[cfg(feature = "enable_ntp")]
-                ntp_pool: cfg.ntp_pool.clone(),
-                #[cfg(feature = "enable_ntp")]
-                ntp_port: cfg.ntp_port,
-                #[cfg(feature = "enable_ntp")]
-                ntp_worker: match cfg.ntp_sync {
-                    true => Some(NtpWorker::create(cfg, tolerance_ms).await?),
-                    false => None,
-                },
-            }
-        )
+        Ok(TimeKeeper {
+            tolerance: tolerance,
+            #[cfg(feature = "enable_ntp")]
+            ntp_pool: cfg.ntp_pool.clone(),
+            #[cfg(feature = "enable_ntp")]
+            ntp_port: cfg.ntp_port,
+            #[cfg(feature = "enable_ntp")]
+            ntp_worker: match cfg.ntp_sync {
+                true => Some(NtpWorker::create(cfg, tolerance_ms).await?),
+                false => None,
+            },
+        })
     }
 
     pub async fn wait_for_high_accuracy(&self) {
@@ -59,7 +53,7 @@ impl TimeKeeper
     pub fn has_converged(&self) -> bool {
         #[cfg(feature = "enable_ntp")]
         if let Some(worker) = &self.ntp_worker {
-            return worker.is_accurate()
+            return worker.is_accurate();
         }
         true
     }
@@ -68,8 +62,7 @@ impl TimeKeeper
         #[cfg(not(feature = "enable_ntp"))]
         {
             let start = SystemTime::now();
-            let since_the_epoch = start
-                .duration_since(UNIX_EPOCH)?;
+            let since_the_epoch = start.duration_since(UNIX_EPOCH)?;
             Ok(since_the_epoch)
         }
         #[cfg(feature = "enable_ntp")]
@@ -77,15 +70,15 @@ impl TimeKeeper
             Some(worker) => worker.current_timestamp()?.since_the_epoch,
             None => {
                 let start = SystemTime::now();
-                let since_the_epoch = start
-                    .duration_since(UNIX_EPOCH)?;
+                let since_the_epoch = start.duration_since(UNIX_EPOCH)?;
                 since_the_epoch
             }
-        })        
+        })
     }
 
-    pub fn current_timestamp(&self) -> Result<ChainTimestamp, TimeError>
-    {
-        Ok(ChainTimestamp::from(self.current_timestamp_as_duration()?.as_millis() as u64))
+    pub fn current_timestamp(&self) -> Result<ChainTimestamp, TimeError> {
+        Ok(ChainTimestamp::from(
+            self.current_timestamp_as_duration()?.as_millis() as u64,
+        ))
     }
-}
\ No newline at end of file
+}
