@@ -1,34 +1,35 @@
-#[allow(unused_imports)]
-use tracing::{error, info, warn, debug};
 use std::sync::Arc;
+#[allow(unused_imports)]
+use tracing::{debug, error, info, warn};
 
 use crate::error::*;
-use crate::sink::*;
-use crate::meta::*;
 use crate::event::*;
+use crate::meta::*;
+use crate::sink::*;
 use crate::transaction::*;
 
 use super::*;
 
-impl EventSink
-for TreeAuthorityPlugin
-{
-    fn feed(&mut self, header: &EventHeader, conversation: Option<&Arc<ConversationSession>>) -> Result<(), SinkError>
-    {        
+impl EventSink for TreeAuthorityPlugin {
+    fn feed(
+        &mut self,
+        header: &EventHeader,
+        conversation: Option<&Arc<ConversationSession>>,
+    ) -> Result<(), SinkError> {
         if let Some(key) = header.meta.get_tombstone() {
             self.auth.remove(&key);
             self.parents.remove(&key);
-        }
-        else if let Some(key) = header.meta.get_data_key() {
-            self.auth.insert(key, match header.meta.get_authorization() {
-                Some(a) => a.clone(),
-                None => {
-                    MetaAuthorization {
+        } else if let Some(key) = header.meta.get_data_key() {
+            self.auth.insert(
+                key,
+                match header.meta.get_authorization() {
+                    Some(a) => a.clone(),
+                    None => MetaAuthorization {
                         read: ReadOption::Inherit,
-                        write: WriteOption::Inherit
-                    }
-                }
-            });
+                        write: WriteOption::Inherit,
+                    },
+                },
+            );
 
             if let Some(parent) = header.meta.get_parent() {
                 if parent.vec.parent_id != key {
@@ -46,4 +47,4 @@ for TreeAuthorityPlugin
         self.parents.clear();
         self.signature_plugin.reset();
     }
-}
\ No newline at end of file
+}
