@@ -1,6 +1,6 @@
 #![allow(unused_imports)]
-use tracing::{info, warn, debug, error, trace, instrument, span, Level};
 use tracing::metadata::LevelFilter;
+use tracing::{debug, error, info, instrument, span, trace, warn, Level};
 use tracing_subscriber::fmt::SubscriberBuilder;
 use tracing_subscriber::EnvFilter;
 
@@ -13,17 +13,24 @@ pub fn log_init(verbose: i32, debug: bool) {
         4 => Some(LevelFilter::TRACE),
         _ => None,
     };
-    if debug { log_level = Some(LevelFilter::DEBUG); }
+    if debug {
+        log_level = Some(LevelFilter::DEBUG);
+    }
 
     if let Some(log_level) = log_level {
-        SubscriberBuilder::default().with_max_level(log_level).init();
+        SubscriberBuilder::default()
+            .with_max_level(log_level)
+            .init();
     } else {
-        SubscriberBuilder::default().with_env_filter(EnvFilter::from_default_env()).init();
+        SubscriberBuilder::default()
+            .with_env_filter(EnvFilter::from_default_env())
+            .init();
     }
 }
 
 pub fn obscure_error<E>(err: E) -> u16
-where E: std::error::Error + Sized
+where
+    E: std::error::Error + Sized,
 {
     let err = err.to_string();
     let hash = (fxhash::hash32(&err) % (u16::MAX as u32)) as u16;
@@ -31,10 +38,9 @@ where E: std::error::Error + Sized
     hash
 }
 
-pub fn obscure_error_str(err: &str) -> u16
-{
+pub fn obscure_error_str(err: &str) -> u16 {
     let err = err.to_string();
     let hash = (fxhash::hash32(&err) % (u16::MAX as u32)) as u16;
     debug!("internal error - code={} - {}", hash, err);
     hash
-}
\ No newline at end of file
+}
